Imprint
-------

*GR* is free software, you can redistribute it and/or modify it under
the terms of the GNU General Public License. The GNU General Public License
does not permit this software to be redistributed in proprietary programs.

This framework is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

**Contact**::

    Scientific IT Systems (J. Heinen)
    Peter Grünberg Institute (PGI) / Jülich Centre for Neutron Science
    Forschungszentrum Jülich
    52425 Jülich

    Phone: +49 2461 61-3912 

This version of the GR website is hosted by the Forschungszentrum Jülich


**Copyright**

Copyright and all other rights concerning the website of Forschungszentrum
Jülich are held by Forschungszentrum Jülich GmbH. Use of the information
contained on the website, including excerpts, is permitted for educational,
scientific or private purposes, provided the source is quoted (unless otherwise
expressly stated on the respective website). Use for commercial purposes is not
permitted unless explicit permission has been granted by Forschungszentrum
Jülich.

**Disclaimer**

The website of Forschungszentrum Jülich has been compiled with due diligence.
However, Forschungszentrum Jülich neither guarantees nor accepts liability for
the information being up-to-date, complete or accurate.

The website of Forschungszentrum Jülich contains links to external third-party
websites. These links to third-party sites do not imply approval of their
contents. Forschungszentrum Jülich has no influence on the current or future
contents of these sites. We therefore accept no liability for the accessibility
or contents of such websites and no liability for damages that may arise as a
result of the use of such content.

-----------------------------

::

    Forschungszentrum Jülich GmbH
    Wilhelm-Johnen-Straße
    52425 Jülich

    Entered in the Commercial Register of the District Court of Düren, Germany: No. HR B 3498
    Value Added Tax ID No. in accordance with § 27 a of the German VAT Law: DE 122624631
    Tax No.: 213/5700/0033

